@@ -1,10 +1,10 @@
-__version__ = "0.0.3"
-__keywords__ = ["telegram telethon telewrapper"]
+__version__ = "0.0.4"
+__keywords__ = ["telegram telethon telewrapper bot api"]
 
 
 # if not __version__.endswith(".0"):
 #     import re
-#     print(f"version {__version__} is deployed for automatic commitments only", flush=True)
+#     print("version {} is deployed for automatic commitments only".format(__version__), flush=True)
 #     print("install version " + re.sub(r"([0-9]+\.[0-9]+\.)[0-9]+", r"\g<1>0", __version__) + " instead")
 #     import os
 #     os._exit(1)
